@@ -1,7 +1,7 @@
 #!/bin/bash
 
 # SPDX-FileCopyrightText: 2015-2016 Collabora Ltd.
-# SPDX-FileCopyrightText: 2020 Ralf Habacker ralf.habacker @freenet.de
+# SPDX-FileCopyrightText: 2020-2024 Ralf Habacker ralf.habacker @freenet.de
 #
 # SPDX-License-Identifier: MIT
 
@@ -22,14 +22,26 @@ set -x
 : "${ci_distro_variant:=leap}"
 
 # ci_variant:
-# One of kf5, kde4
+# One of kf5, kf4
 : "${ci_variant:=kf5}"
 
+# ci_webserver:
+# if yes, install simple webserver
+: "${ci_webserver:=yes}"
+
 # setup install command; use sudo outside of docker
-sudo=
-if ! [ -f /.dockerenv ]; then
+# found on https://stackoverflow.com/questions/23513045
+case $(cat /proc/1/sched  | head -n 1 | cut -d' ' -f1) in
+  systemd|init)
     sudo=sudo
-fi
+    ci_in_docker="no"
+    ;;
+  *)
+    ci_in_docker="yes"
+    sudo=
+    ;;
+esac
+
 zypper="$sudo /usr/bin/zypper --non-interactive"
 
 install=
@@ -44,6 +56,19 @@ case "$ci_distro" in
         # add required repos
         repo_name=$(. /etc/os-release; echo $PRETTY_NAME | sed 's, ,_,g')
         repos=()
+        # install newest cmake
+        case "$repo_name" in
+            (*Leap*)
+                devel_tools_building_repo_name=$(. /etc/os-release; echo $VERSION_ID)
+                ;;
+            (*Tumbleweed*)
+                devel_tools_building_repo_name=openSUSE_Factory
+                ;;
+        esac
+        repos=(
+            "${repos[@]}"
+            https://download.opensuse.org/repositories/devel:/tools:/building/$devel_tools_building_repo_name/devel:tools:building.repo
+        )
         case "$ci_variant-$ci_host" in
             (*-mingw*)
                 bits=$(echo $ci_host | sed 's,mingw,,g')
@@ -54,7 +79,14 @@ case "$ci_distro" in
                     https://download.opensuse.org/repositories/security:/tls/openSUSE_Tumbleweed/security:tls.repo
                 )
                 ;;
-            (kde4-native)
+            (kf6-native)
+                repos=(
+                    "${repos[@]}"
+                    https://download.opensuse.org/repositories/KDE:/Unstable:/Frameworks/openSUSE_Factory/KDE:Unstable:Frameworks.repo
+                )
+                ;;
+
+            (kf4-native)
                 repos=(
                     "${repos[@]}"
                     https://download.opensuse.org/repositories/windows:/mingw/${repo_name}/windows:mingw.repo
@@ -72,11 +104,15 @@ case "$ci_distro" in
         # misc packages
         packages=(
            "${packages[@]}"
+            gawk
             gettext-runtime
+            # for catching segfaults
+            gdb
             # prevents crashing of mingwxx-windres (https://bugzilla.opensuse.org/show_bug.cgi?id=1198923)
             glibc-locale-base
             # xvfb-run does not have added all required tools
             openbox
+            procps # ps
             psmisc # killall
             shadow # useradd
             sharutils # uuencode
@@ -87,12 +123,47 @@ case "$ci_distro" in
             xterm
         )
 
+        if [ "$ci_webserver" = "yes" ]; then
+            packages=(
+            "${packages[@]}"
+                php8-cli # webserver
+            )
+        fi
+
         # for screenshots
         packages=(
            "${packages[@]}"
             xwd ImageMagick
         )
         case "$ci_variant-$ci_host" in
+            (kf6*-native)
+                source_packages=(
+                    "${source_packages[@]}"
+                )
+                packages=(
+                    "${packages[@]}"
+                    kinit
+                    "cmake(KF6Completion)"
+                    "cmake(KF6Config)"
+                    "cmake(KF6CoreAddons)"
+                    "cmake(KF6I18n)"
+                    "cmake(KF6IconThemes)"
+                    "cmake(KF6KIO)"
+                    "cmake(KF6NewStuff)"
+                    "cmake(KF6NewStuffCore)"
+                    "cmake(KF6Package)"
+                    "cmake(KF6TextWidgets)"
+                    "cmake(KF6WidgetsAddons)"
+                    "cmake(Qt6Core)"
+                    "cmake(Qt6DBus)"
+                    "cmake(Qt6Qml)"
+                    "cmake(Qt6Test)"
+                    "cmake(Qt6Widgets)"
+                    "doxygen"
+                    "gmp-devel"
+                    "kf6-extra-cmake-modules"
+                )
+                ;;
             (kf5*-native)
                 source_packages=(
                     "${source_packages[@]}"
@@ -128,7 +199,7 @@ case "$ci_distro" in
                     wine
                 )
                 ;;
-            (kde4-native)
+            (kf4-native)
                 # for libQtWebKit-devel
                 packages=(
                     "${packages[@]}"
@@ -140,13 +211,13 @@ case "$ci_distro" in
                     gmp-devel
                 )
                 ;;
-            (kde4-mingw*)
+            (kf4-mingw*)
                 prefix=${ci_host}
                 packages=(
                     "${packages[@]}"
                     ${prefix}-cross-gcc-c++
                     ${prefix}-extra-cmake-modules
-                    ${prefix}-libkde4-devel
+                    ${prefix}-libkf4-devel
                     ${prefix}-gmp-devel
                     wine
                 )
@@ -161,13 +232,21 @@ case "$ci_distro" in
             (kf5-webkit)
                 packages=(
                     "${packages[@]}"
-                    libQt5WebKitWidgets-devel
+                    "cmake(Qt5WebKitWidgets)"
                 )
                 ;;
             (kf5-webengine)
                 packages=(
                     "${packages[@]}"
-                    libqt5-qtwebengine-devel
+                    "google-droid-fonts"
+                    "cmake(Qt5WebEngineWidgets)"
+                )
+                ;;
+            (kf6-webengine)
+                packages=(
+                    "${packages[@]}"
+                    "google-droid-fonts"
+                    "cmake(Qt6WebEngineWidgets)"
                 )
                 ;;
         esac
@@ -191,7 +270,7 @@ esac
 
 # Add the user that we will use to do the build inside the
 # Docker container, and let them use sudo
-if [ -f /.dockerenv ] && [ -z `getent passwd | grep ^user` ]; then
+if [ "$ci_in_docker" = "yes" ] && [ -z `getent passwd | grep ^user` ]; then
     useradd -m user
     passwd -ud user
     echo "user ALL=(ALL) NOPASSWD: ALL" > /etc/sudoers.d/nopasswd
